diff --git a/core/modules/field_ui/field_ui.module b/core/modules/field_ui/field_ui.module
index 0d81232..030d983 100644
--- a/core/modules/field_ui/field_ui.module
+++ b/core/modules/field_ui/field_ui.module
@@ -91,7 +91,7 @@ function field_ui_menu() {
         'type' => MENU_DEFAULT_LOCAL_TASK,
       );
       $items["$path/fields/%/field"] = array(
-        'title' => 'Field settings',
+        'title' => 'Global settings',
         'type' => MENU_LOCAL_TASK,
         'route_name' => "field_ui.field_edit_$entity_type",
       );
diff --git a/core/modules/field_ui/lib/Drupal/field_ui/Form/FieldEditForm.php b/core/modules/field_ui/lib/Drupal/field_ui/Form/FieldEditForm.php
index 67fa7d6..665c2b3 100644
--- a/core/modules/field_ui/lib/Drupal/field_ui/Form/FieldEditForm.php
+++ b/core/modules/field_ui/lib/Drupal/field_ui/Form/FieldEditForm.php
@@ -163,7 +163,7 @@ public function buildForm(array $form, array &$form_state, FieldInstanceInterfac
     $form['field']['settings'] += $entity->get($field['field_name'])->offsetGet(0)->settingsForm($form, $form_state, $field->hasData());
 
     $form['actions'] = array('#type' => 'actions');
-    $form['actions']['submit'] = array('#type' => 'submit', '#value' => $this->t('Save field settings'));
+    $form['actions']['submit'] = array('#type' => 'submit', '#value' => $this->t('Save global field settings'));
     return $form;
   }
 
diff --git a/core/modules/field_ui/lib/Drupal/field_ui/Tests/FieldUiTestBase.php b/core/modules/field_ui/lib/Drupal/field_ui/Tests/FieldUiTestBase.php
index 9116d09..aa9d6f9 100644
--- a/core/modules/field_ui/lib/Drupal/field_ui/Tests/FieldUiTestBase.php
+++ b/core/modules/field_ui/lib/Drupal/field_ui/Tests/FieldUiTestBase.php
@@ -75,7 +75,7 @@ function fieldUIAddNewField($bundle_path, $initial_edit, $field_edit = array(),
     $this->assertRaw(t('These settings apply to the %label field everywhere it is used.', array('%label' => $label)), 'Field settings page was displayed.');
 
     // Second step : 'Field settings' form.
-    $this->drupalPostForm(NULL, $field_edit, t('Save field settings'));
+    $this->drupalPost(NULL, $field_edit, t('Save global field settings'));
     $this->assertRaw(t('Updated field %label field settings.', array('%label' => $label)), 'Redirected to instance and widget settings page.');
 
     // Third step : 'Instance settings' form.
diff --git a/core/modules/field_ui/lib/Drupal/field_ui/Tests/ManageFieldsTest.php b/core/modules/field_ui/lib/Drupal/field_ui/Tests/ManageFieldsTest.php
index 79b1fbe..a464aca 100644
--- a/core/modules/field_ui/lib/Drupal/field_ui/Tests/ManageFieldsTest.php
+++ b/core/modules/field_ui/lib/Drupal/field_ui/Tests/ManageFieldsTest.php
@@ -132,7 +132,7 @@ function updateField() {
     $edit = array(
       'field[settings][test_field_setting]' => $string,
     );
-    $this->drupalPostForm(NULL, $edit, t('Save field settings'));
+    $this->drupalPost(NULL, $edit, t('Save global field settings'));
 
     // Go to the field instance edit page.
     $this->drupalGet('admin/structure/types/manage/' . $this->type . '/fields/' . $instance_id);
@@ -183,7 +183,7 @@ function cardinalitySettings() {
       'field[cardinality]' => 'number',
       'field[cardinality_number]' => '',
     );
-    $this->drupalPostForm($field_edit_path, $edit, t('Save field settings'));
+    $this->drupalPost($field_edit_path, $edit, t('Save global field settings'));
     $this->assertText('Number of values is required.');
 
     // Submit a custom number.
@@ -191,7 +191,7 @@ function cardinalitySettings() {
       'field[cardinality]' => 'number',
       'field[cardinality_number]' => 6,
     );
-    $this->drupalPostForm($field_edit_path, $edit, t('Save field settings'));
+    $this->drupalPost($field_edit_path, $edit, t('Save global field settings'));
     $this->assertText('Updated field Body field settings.');
     $this->drupalGet($field_edit_path);
     $this->assertFieldByXPath("//select[@name='field[cardinality]']", 'number');
@@ -201,7 +201,7 @@ function cardinalitySettings() {
     $edit = array(
       'field[cardinality]' => FIELD_CARDINALITY_UNLIMITED,
     );
-    $this->drupalPostForm($field_edit_path, $edit, t('Save field settings'));
+    $this->drupalPost($field_edit_path, $edit, t('Save global field settings'));
     $this->assertText('Updated field Body field settings.');
     $this->drupalGet($field_edit_path);
     $this->assertFieldByXPath("//select[@name='field[cardinality]']", FIELD_CARDINALITY_UNLIMITED);
diff --git a/core/modules/file/lib/Drupal/file/Tests/FileFieldWidgetTest.php b/core/modules/file/lib/Drupal/file/Tests/FileFieldWidgetTest.php
index d328bd5..e0ace0b 100644
--- a/core/modules/file/lib/Drupal/file/Tests/FileFieldWidgetTest.php
+++ b/core/modules/file/lib/Drupal/file/Tests/FileFieldWidgetTest.php
@@ -214,7 +214,7 @@ function testPrivateFileSetting() {
 
     // Change the field setting to make its files private, and upload a file.
     $edit = array('field[settings][uri_scheme]' => 'private');
-    $this->drupalPostForm("admin/structure/types/manage/$type_name/fields/$instance->id/field", $edit, t('Save field settings'));
+    $this->drupalPost("admin/structure/types/manage/$type_name/fields/$instance->id/field", $edit, t('Save global field settings'));
     $nid = $this->uploadNodeFile($test_file, $field_name, $type_name);
     $node = node_load($nid, TRUE);
     $node_file = file_load($node->{$field_name}->target_id);
@@ -259,8 +259,8 @@ function testPrivateFileComment() {
     );
     $this->drupalPostForm('admin/structure/comments/manage/node__comment/fields', $edit, t('Save'));
     $edit = array('field[settings][uri_scheme]' => 'private');
-    $this->drupalPostForm(NULL, $edit, t('Save field settings'));
-    $this->drupalPostForm(NULL, array(), t('Save settings'));
+    $this->drupalPost(NULL, $edit, t('Save global field settings'));
+    $this->drupalPost(NULL, array(), t('Save settings'));
 
     // Manually clear cache on the tester side.
     field_info_cache_clear();
diff --git a/core/modules/image/lib/Drupal/image/Tests/ImageFieldDisplayTest.php b/core/modules/image/lib/Drupal/image/Tests/ImageFieldDisplayTest.php
index 5c27462..4f26725 100644
--- a/core/modules/image/lib/Drupal/image/Tests/ImageFieldDisplayTest.php
+++ b/core/modules/image/lib/Drupal/image/Tests/ImageFieldDisplayTest.php
@@ -244,7 +244,7 @@ function testImageFieldDefaultImage() {
     $edit = array(
       'files[field_settings_default_image]' => drupal_realpath($images[0]->uri),
     );
-    $this->drupalPostForm("admin/structure/types/manage/article/fields/node.article.$field_name/field", $edit, t('Save field settings'));
+    $this->drupalPost("admin/structure/types/manage/article/fields/node.article.$field_name/field", $edit, t('Save global field settings'));
     // Clear field info cache so the new default image is detected.
     field_info_cache_clear();
     $field = field_info_field('node', $field_name);
@@ -277,7 +277,7 @@ function testImageFieldDefaultImage() {
     $edit = array(
       'field[settings][default_image][fids]' => 0,
     );
-    $this->drupalPostForm("admin/structure/types/manage/article/fields/node.article.$field_name/field", $edit, t('Save field settings'));
+    $this->drupalPost("admin/structure/types/manage/article/fields/node.article.$field_name/field", $edit, t('Save global field settings'));
     // Clear field info cache so the new default image is detected.
     field_info_cache_clear();
     $field = field_info_field('node', $field_name);
@@ -290,7 +290,7 @@ function testImageFieldDefaultImage() {
     $edit = array(
       'files[field_settings_default_image]' => drupal_realpath($images[1]->uri),
     );
-    $this->drupalPostForm('admin/structure/types/manage/article/fields/node.article.' . $private_field_name . '/field', $edit, t('Save field settings'));
+    $this->drupalPost('admin/structure/types/manage/article/fields/node.article.' . $private_field_name . '/field', $edit, t('Save global field settings'));
     // Clear field info cache so the new default image is detected.
     field_info_cache_clear();
 

diff --git a/core/modules/field_ui/lib/Drupal/field_ui/FieldOverview.php b/core/modules/field_ui/lib/Drupal/field_ui/FieldOverview.php
index a2dbb68..0b471c1 100644
--- a/core/modules/field_ui/lib/Drupal/field_ui/FieldOverview.php
+++ b/core/modules/field_ui/lib/Drupal/field_ui/FieldOverview.php
@@ -134,7 +134,7 @@ public function buildForm(array $form, array &$form_state, $entity_type = NULL,
           '#type' => 'link',
           '#title' => $field_types[$field['type']]['label'],
           '#href' => $admin_field_path . '/field',
-          '#options' => array('attributes' => array('title' => $this->t('Edit field settings.'))),
+          '#options' => array('attributes' => array('title' => $this->t('Edit global field settings.'))),
         ),
       );
 
@@ -147,7 +147,7 @@ public function buildForm(array $form, array &$form_state, $entity_type = NULL,
       $links['field-settings'] = array(
         'title' => $this->t('Field settings'),
         'href' => $admin_field_path . '/field',
-        'attributes' => array('title' => $this->t('Edit field settings.')),
+        'attributes' => array('title' => $this->t('Edit global field settings.')),
       );
       $links['delete'] = array(
         'title' => $this->t('Delete'),
@@ -414,8 +414,8 @@ public function submitForm(array &$form, array &$form_state) {
           ->setComponent($values['field_name'])
           ->save();
 
         // Always show the field settings step, as the cardinality needs to be
         // configured for new fields.
         $destinations[] = $this->adminPath. '/fields/' . $new_instance->id() . '/field';
         $destinations[] = $this->adminPath . '/fields/' . $new_instance->id();
 
@@ -414,8 +414,8 @@ public function submitForm(array &$form, array &$form_state) {
           ->save();
 
-        // Always show the field settings step, as the cardinality needs to be
-        // configured for new fields.
+        // Always show the global field settings step, as the cardinality needs
+        // to be configured for new fields.
         $destinations[] = $this->adminPath. '/fields/' . $new_instance->id() . '/field';
         $destinations[] = $this->adminPath . '/fields/' . $new_instance->id();